@@ -1,7 +1,8 @@
 #!/usr/bin/env python
 # coding=utf-8
 """A sample application for cmd2 showing how to use Argparse to process command line arguments for your application.
-It doubles as an example of how you can still do transcript testing even if allow_cli_args is false.
+It parses command line arguments looking for known arguments, but then still passes any unknown arguments onto cmd2
+to treat them as arguments at invocation.
 
 Thanks to cmd2's built-in transcript testing capability, it also serves as a test suite for argparse_example.py when
 used with the exampleSession.txt transcript.
@@ -10,6 +11,7 @@ Running `python argparse_example.py -t exampleSession.txt` will run all the comm
 argparse_example.py, verifying that the output produced matches the transcript.
 """
 import argparse
+import sys
 
 from cmd2 import Cmd, make_option, options
 
@@ -28,7 +30,7 @@ class CmdLineApp(Cmd):
         Cmd.__init__(self, use_ipython=False, transcript_files=transcript_files)
 
         # Disable cmd's usage of command-line arguments as commands to be run at invocation
-        self.allow_cli_args = False
+        # self.allow_cli_args = False
 
         # Example of args set from the command-line (but they aren't being used here)
         self._ip = ip_addr
@@ -68,8 +70,7 @@ if __name__ == '__main__':
     parser.add_argument('-i', '--ip', type=str, help='IPv4 address')
 
     # Add an argument which enables transcript testing
-    parser.add_argument('-t', '--test', type=str, help='Test against transcript in FILE (wildcards OK)')
-    args = parser.parse_args()
+    args, unknown_args = parser.parse_known_args()
 
     port = None
     if args.port:
@@ -79,12 +80,11 @@ if __name__ == '__main__':
     if args.ip:
         ip_addr = args.ip
 
-    transcripts = None
-    if args.test:
-        transcripts = [args.test]
+    # Perform surgery on sys.argv to remove the arguments which have already been processed by argparse
+    sys.argv = sys.argv[:1] + unknown_args
 
     # Instantiate your cmd2 application
-    c = CmdLineApp(transcript_files=transcripts)
+    c = CmdLineApp()
 
     # And run your cmd2 application
     c.cmdloop()
