@@ -36,7 +36,7 @@ Options:
 """
 
 # Output from the shortcuts command with default built-in shortcuts
-SHORTCUTS_TXT = """Single-key shortcuts for other commands:
+SHORTCUTS_TXT = """Shortcuts for other commands:
 !: shell
 ?: help
 @: load
@@ -47,15 +47,14 @@ expect_colors = True
 if sys.platform.startswith('win'):
     expect_colors = False
 # Output from the show command with default settings
-SHOW_TXT = """abbrev: True
+SHOW_TXT = """abbrev: False
 autorun_on_edit: False
-case_insensitive: True
 colors: {}
 continuation_prompt: >
 debug: False
 echo: False
 editor: vim
-feedback_to_output: True
+feedback_to_output: False
 locals_in_py: True
 prompt: (Cmd)
 quiet: False
@@ -67,19 +66,18 @@ if expect_colors:
 else:
     color_str = 'False'
 SHOW_LONG = """
-abbrev: True             # Accept abbreviated commands
-autorun_on_edit: False   # Automatically run files after editing
-case_insensitive: True   # Upper- and lower-case both OK
-colors: {}            # Colorized output (*nix only)
-continuation_prompt: >   # On 2nd+ line of input
-debug: False             # Show full error stack on error
-echo: False              # Echo command issued into output
-editor: vim              # Program used by ``edit``
-feedback_to_output: True # Include nonessentials in `|`, `>` results
-locals_in_py: True       # Allow access to your application in py via self
-prompt: (Cmd)            # The prompt issued to solicit input
-quiet: False             # Don't print nonessential feedback
-timing: False            # Report execution times
+abbrev: False             # Accept abbreviated commands
+autorun_on_edit: False    # Automatically run files after editing
+colors: {}             # Colorized output (*nix only)
+continuation_prompt: >    # On 2nd+ line of input
+debug: False              # Show full error stack on error
+echo: False               # Echo command issued into output
+editor: vim               # Program used by ``edit``
+feedback_to_output: False # Include nonessentials in `|`, `>` results
+locals_in_py: True        # Allow access to your application in py via self
+prompt: (Cmd)             # The prompt issued to solicit input
+quiet: False              # Don't print nonessential feedback
+timing: False             # Report execution times
 """.format(color_str)
 
 
