@@ -24,7 +24,7 @@ from conftest import run_cmd, normalize, BASE_HELP, HELP_HISTORY, SHORTCUTS_TXT,
 
 
 def test_ver():
-    assert cmd2.__version__ == '0.7.7'
+    assert cmd2.__version__ == '0.7.9'
 
 
 def test_empty_statement(base_app):
@@ -401,6 +401,61 @@ def test_load_with_utf8_file(base_app, capsys, request):
     assert base_app._current_script_dir == sdir
 
 
+def test_load_nested_loads(base_app, request):
+    # Verify that loading a script with nested load commands works correctly,
+    # and loads the nested script commands in the correct order. The recursive
+    # loads don't happen all at once, but as the commands are interpreted. So,
+    # we will need to drain the cmdqueue and inspect the stdout to see if all
+    # steps were executed in the expected order.
+    test_dir = os.path.dirname(request.module.__file__)
+    filename = os.path.join(test_dir, 'scripts', 'nested.txt')
+    assert base_app.cmdqueue == []
+
+    # Load the top level script and then run the command queue until all
+    # commands have been exhausted.
+    initial_load = 'load ' + filename
+    run_cmd(base_app, initial_load)
+    while base_app.cmdqueue:
+        base_app.onecmd_plus_hooks(base_app.cmdqueue.pop(0))
+
+    # Check that the right commands were executed.
+    expected = """
+%s
+_relative_load precmds.txt
+set abbrev on
+set colors on
+help
+shortcuts
+_relative_load postcmds.txt
+set abbrev off
+set colors off""" % initial_load
+    assert run_cmd(base_app, 'history -s') == normalize(expected)
+
+
+def test_base_runcmds_plus_hooks(base_app, request):
+    # Make sure that runcmds_plus_hooks works as intended. I.E. to run multiple
+    # commands and process any commands added, by them, to the command queue.
+    test_dir = os.path.dirname(request.module.__file__)
+    prefilepath = os.path.join(test_dir, 'scripts', 'precmds.txt')
+    postfilepath = os.path.join(test_dir, 'scripts', 'postcmds.txt')
+    assert base_app.cmdqueue == []
+
+    base_app.runcmds_plus_hooks(['load ' + prefilepath,
+                                 'help',
+                                 'shortcuts',
+                                 'load ' + postfilepath])
+    expected = """
+load %s
+set abbrev on
+set colors on
+help
+shortcuts
+load %s
+set abbrev off
+set colors off""" % (prefilepath, postfilepath)
+    assert run_cmd(base_app, 'history -s') == normalize(expected)
+
+
 def test_base_relative_load(base_app, request):
     test_dir = os.path.dirname(request.module.__file__)
     filename = os.path.join(test_dir, 'script.txt')
@@ -757,22 +812,6 @@ def test_edit_file_with_spaces(base_app, request, monkeypatch):
     # We think we have an editor, so should expect a system call
     m.assert_called_once_with('"{}" "{}"'.format(base_app.editor, filename))
 
-def test_edit_number(base_app, monkeypatch):
-    # Set a fake editor just to make sure we have one.  We aren't really going to call it due to the mock
-    base_app.editor = 'fooedit'
-
-    # Mock out the os.system call so we don't actually open an editor
-    m = mock.MagicMock(name='system')
-    monkeypatch.setattr("os.system", m)
-
-    # Run help command just so we have a command in history
-    run_cmd(base_app, 'help')
-
-    run_cmd(base_app, 'edit 1')
-
-    # We have an editor, so should expect a system call
-    m.assert_called_once()
-
 def test_edit_blank(base_app, monkeypatch):
     # Set a fake editor just to make sure we have one.  We aren't really going to call it due to the mock
     base_app.editor = 'fooedit'
@@ -795,6 +834,70 @@ def test_edit_empty_history(base_app, capsys):
     assert out == ''
     assert err == 'ERROR: edit must be called with argument if history is empty\n'
 
+def test_edit_valid_positive_number(base_app, monkeypatch):
+    # Set a fake editor just to make sure we have one.  We aren't really going to call it due to the mock
+    base_app.editor = 'fooedit'
+
+    # Mock out the os.system call so we don't actually open an editor
+    m = mock.MagicMock(name='system')
+    monkeypatch.setattr("os.system", m)
+
+    # Run help command just so we have a command in history
+    run_cmd(base_app, 'help')
+
+    run_cmd(base_app, 'edit 1')
+
+    # We have an editor, so should expect a system call
+    m.assert_called_once()
+
+def test_edit_valid_negative_number(base_app, monkeypatch):
+    # Set a fake editor just to make sure we have one.  We aren't really going to call it due to the mock
+    base_app.editor = 'fooedit'
+
+    # Mock out the os.system call so we don't actually open an editor
+    m = mock.MagicMock(name='system')
+    monkeypatch.setattr("os.system", m)
+
+    # Run help command just so we have a command in history
+    run_cmd(base_app, 'help')
+
+    run_cmd(base_app, 'edit "-1"')
+
+    # We have an editor, so should expect a system call
+    m.assert_called_once()
+
+def test_edit_invalid_positive_number(base_app, monkeypatch):
+    # Set a fake editor just to make sure we have one.  We aren't really going to call it due to the mock
+    base_app.editor = 'fooedit'
+
+    # Mock out the os.system call so we don't actually open an editor
+    m = mock.MagicMock(name='system')
+    monkeypatch.setattr("os.system", m)
+
+    # Run help command just so we have a command in history
+    run_cmd(base_app, 'help')
+
+    run_cmd(base_app, 'edit 23')
+
+    # History index is invalid, so should expect a system call
+    m.assert_not_called()
+
+def test_edit_invalid_negative_number(base_app, monkeypatch):
+    # Set a fake editor just to make sure we have one.  We aren't really going to call it due to the mock
+    base_app.editor = 'fooedit'
+
+    # Mock out the os.system call so we don't actually open an editor
+    m = mock.MagicMock(name='system')
+    monkeypatch.setattr("os.system", m)
+
+    # Run help command just so we have a command in history
+    run_cmd(base_app, 'help')
+
+    run_cmd(base_app, 'edit "-23"')
+
+    # History index is invalid, so should expect a system call
+    m.assert_not_called()
+
 
 def test_base_py_interactive(base_app):
     # Mock out the InteractiveConsole.interact() call so we don't actually wait for a user's response on stdin
@@ -1406,7 +1509,7 @@ def test_pseudo_raw_input_tty_rawinput_true():
             # for the 'set' command, and once for the 'quit' command,
             # that the rest of it worked
             assert m_input.call_count == 2
-    
+
 def test_pseudo_raw_input_tty_rawinput_false():
     # gin up some input like it's coming from a tty
     fakein = io.StringIO(u'{}'.format('set\n'))
@@ -1414,12 +1517,12 @@ def test_pseudo_raw_input_tty_rawinput_false():
     fakein.isatty = mtty
     mreadline = mock.MagicMock(name='readline', wraps=fakein.readline)
     fakein.readline = mreadline
-    
+
     # run the cmdloop, telling it where to get input from
     app = cmd2.Cmd(stdin=fakein)
     app.use_rawinput = False
     app._cmdloop()
-    
+
     # because we mocked the readline() call, we won't get the prompt
     # or the name of the command in the output, so we can't check
     # if its there. We assume that if readline() got called twice, once
@@ -1523,3 +1626,32 @@ def test_empty_stdin_input():
 
     line = app.pseudo_raw_input('(cmd2)')
     assert line == 'eof'
+
+
+def test_poutput_string(base_app):
+    msg = 'This is a test'
+    base_app.poutput(msg)
+    out = base_app.stdout.buffer
+    expected = msg + '\n'
+    assert out == expected
+
+def test_poutput_zero(base_app):
+    msg = 0
+    base_app.poutput(msg)
+    out = base_app.stdout.buffer
+    expected = str(msg) + '\n'
+    assert out == expected
+
+def test_poutput_empty_string(base_app):
+    msg = ''
+    base_app.poutput(msg)
+    out = base_app.stdout.buffer
+    expected = msg
+    assert out == expected
+
+def test_poutput_none(base_app):
+    msg = None
+    base_app.poutput(msg)
+    out = base_app.stdout.buffer
+    expected = ''
+    assert out == expected
